==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits");
define("_BROWSERS","Browsere");
define("_OPERATINGSYS","Operativsystemer");
define("_UNKNOWN","Ukendt");
define("_OTHER","Andre / Ukendt");
define("_MISCSTATS","Forskellige statistikker");
define("_REGUSERS","Registrede brugere:");
define("_ACTIVEAUTHORS","Administratorer:");
define("_STORIESPUBLISHED","Artikler publiceret:");
define("_SACTIVETOPICS","Antal emner:");
define("_COMMENTSPOSTED","Kommentarer postet:");
define("_SSPECIALSECT","Sektioner:");
define("_ARTICLESSEC","Artikler i sektioner:");
define("_LINKSINLINKS","Links i databasen:");
define("_LINKSCAT","Kategorier under Links:");
define("_NEWSWAITING","Artikler der venter p at blive publiceret:");
define("_NUKEVERSION","PHP-Nuke version:");
define("_SEARCHENGINES","Sgemaskiner");
define("_BOTS","Sgerobotter");
define("_STATS","- Statistik");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits");
define("_BROWSERS","Browsere");
define("_OPERATINGSYS","Operativsystemer");
define("_UNKNOWN","Ukendt");
define("_OTHER","Andre / Ukendt");
define("_MISCSTATS","Forskellige statistikker");
define("_REGUSERS","Registrede brugere:");
define("_ACTIVEAUTHORS","Administratorer:");
define("_STORIESPUBLISHED","Artikler publiceret:");
define("_SACTIVETOPICS","Antal emner:");
define("_COMMENTSPOSTED","Kommentarer postet:");
define("_SSPECIALSECT","Sektioner:");
define("_ARTICLESSEC","Artikler i sektioner:");
define("_LINKSINLINKS","Links i databasen:");
define("_LINKSCAT","Kategorier under Links:");
define("_NEWSWAITING","Artikler der venter p at blive publiceret:");
define("_NUKEVERSION","PHP-Nuke version:");
define("_SEARCHENGINES","Sgemaskiner");
define("_BOTS","Sgerobotter");
define("_STATS","- Statistik");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
